<!--新增修改页面-->
<template>
  <div class="function-page">
    <div class="title-box">
      <el-page-header @back="closePage" :content="title" />
    </div>
    <div class="form-content">
      <el-form
        ref="addModifyFromRef"
        :rules="rules"
        :model="formData"
        label-width="120px"
        label-suffix=":"
      >
        <el-row>
          <el-col :span="8">
            <el-form-item label="巡检计划名称" prop="inspectionPlanName">
              <el-input
                :clearable="false"
                placeholder="请输入巡检计划名称"
                v-model="formData.inspectionPlanName"
                maxlength="100"
                show-word-limit
              />
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="巡检时间" prop="inspectionPlanTime">
              <el-date-picker
                :clearable="false"
                type="date"
                value-format="yyyy-MM-dd"
                style="width:100%"
                placeholder="请选择巡检时间"
                v-model="formData.inspectionPlanTime"
              />
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="巡检类型" prop="inspectionType">
              <el-select
                placeholder="请选择巡检类型"
                v-model="formData.inspectionType"
                style="width: 100%;"
              >
                <el-option
                  v-for="item in inspectionTypeOpt"
                  :key="item.value"
                  :label="item.name"
                  :value="item.value"
                />
              </el-select>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="24">
            <el-form-item label="巡检内容" prop="inspectionContent">
              <el-input
                :clearable="false"
                placeholder="请输入巡检内容"
                v-model="formData.inspectionContent"
                type="textarea"
                :autosize="{ minRows: 3, maxRows: 4}"
                maxlength="100"
                show-word-limit
              />
            </el-form-item>
          </el-col>
        </el-row>
        <el-row>
          <el-col :span="24">
            <el-form-item label="巡检设备" prop="resultDtoList">
              <div class="tage-content">
                <el-tag
                  v-for="(item,index) in formData.resultDtoList"
                  size="medium"
                  :key="index"
                  :effect="
                    item.productId === formData.productId ? 'dark' : ( item.isHover ? 'light' : 'plain')
                  "
                  :closable="true"
                  :disable-transitions="false"
                  @mouseenter.native="item.isHover = true"
                  @mouseleave.native="item.isHover = false"
                  @click="equipClick(item)"
                  @close="equipClose(item,index)"
                >
                  {{ item.productName }}
                </el-tag>
                <el-button
                  size="mini"
                  @click="showDialog('inspectEquipDialog')"
                >
                  + 添加巡检设备
                </el-button>
              </div>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
      <div class="equip-table-content">
        <template v-if="formData.resultDtoList.length">
          <!--     设备列表     -->
          <DeviceList
            :productId="formData.productId"
            ref="deviceListRef"
            :resultDto="resultDto"
          />
        </template>
      </div>
      <div class="btn-content">
        <el-button
          type="primary"
          @click="handleSaveData"
          size="medium"
        >
          保 存
        </el-button>
        <el-button @click="closePage" size="medium">取 消</el-button>
      </div>
    </div>

    <!--  选择设备弹层  -->
    <InspectionEquipmentDialog
      :inspectEquipDialog.sync="inspectEquipDialog"
      :resultDtoList.sync="formData.resultDtoList"
      @equipSelect="equipSelect"
    />
  </div>
</template>

<script>
import {
  deviceInspectionPlanAdd,
  deviceInspectionPlanDetails,
  deviceInspectionPlanEdit
} from '@/api/device/resourceInspection/resourceInspection'

import InspectionEquipmentDialog from './components/InspectionEquipmentDialog.vue'
import DeviceList from './components/DeviceList.vue'

export default {
  name: 'AddModifyDialog',
  components: {DeviceList, InspectionEquipmentDialog},
  props: {
    rowInfo: {
      default: _ => ({}),
      type: Object
    },
    inspectionTypeOpt: {
      default: _ => ([]),
      type: Array
    }
  },
  computed: {
    resultDto() {
      return this.formData.resultDtoList.find(i => i.productId === this.formData.productId)
    }
  },
  data() {
    return {
      title: '标题',
      formData: {
        productId: '', // 选中的设备Id（前端自定义字段）
        productTable: [], // 选中的设备列表（前端自定义字段）
        resultDtoList: []
      },
      rules: {
        inspectionPlanName: [
          {required: true, message: '巡检计划名称不能为空', trigger: 'blur'}
        ],
        inspectionPlanTime: [
          {required: true, message: '巡检时间不能为空', trigger: 'blur'}
        ],
        inspectionType: [
          {required: true, message: '巡检类型不能为空', trigger: 'blur'}
        ],
        inspectionContent: [
          {required: true, message: '巡检内容不能为空', trigger: 'change'}
        ],
        resultDtoList: [
          {required: true, message: '巡检设备不能为空,请添加巡检设备', trigger: 'change'}
        ]
      },
      inspectEquipDialog: false // 选择设备弹层显隐
    }
  },
  created() {
    this.openPage()
  },
  methods: {
    // 弹层打开
    openPage() {
      let title = ''
      if (this.rowInfo.id) {
        title = '编辑'
        this.getDetails(this.rowInfo.id)
      } else {
        title = '新增'
      }
      this.title = `${title}巡检计划`
    },

    // 弹层关闭
    closePage() {
      this.$emit('closePage')
      this.formData = this.$options.data().formData
      this.$refs.addModifyFromRef.resetFields()
    },

    // 获取详情
    async getDetails(id) {
      const {resultDtoList, ...formData} = (await deviceInspectionPlanDetails(id)).value || {}
      this.formData = {
        ...formData,
        productId: resultDtoList[0]?.productId || '',
        resultDtoList: resultDtoList.map(i => ({...i, isHover: false}))
      }
    },

    // 保存
    handleSaveData() {
      this.$refs.addModifyFromRef.validate(async (valid, object) => {
        if (!valid) {
          this.$message.warning(`有${Object.keys(object).length}个字段未通过校验，请正确填写表单内容。`)
        } else {
          let message, interF, args

          if (this.rowInfo.id) {
            message = '编辑'
            interF = deviceInspectionPlanEdit
            args = 'modify'
          } else {
            message = '新增'
            interF = deviceInspectionPlanAdd
            args = 'add'
          }
          const loading = this.$loading({
            lock: true,
            text: `正在${message}巡检计划中，请勿操作系统...`,
            spinner: 'el-icon-loading',
            background: 'rgba(255, 255, 255, 0.9)'
          })

          const {state} = await interF(this.formData)
          if (state) {
            this.$message.success(message + '巡检计划成功')
            this.$emit('closePage', args)
          } else {
            this.$message.error(message + '巡检计划失败')
          }
          loading.close()
        }
      })
    },

    // 设备选择后
    equipSelect() {
      this.$refs.deviceListRef && this.$refs.deviceListRef.calcTableHeight()
      if (!this.formData.productId) {
        this.formData.productId = this.formData.resultDtoList[0]?.productId || ''
      }
    },

    // 设备分类点击后
    equipClick(item) {
      if (!item.productId) return
      this.$refs.deviceListRef && this.$refs.deviceListRef.calcTableHeight()
      this.formData.productId = item.productId
    },

    // 设备分类关闭后
    equipClose(item, index) {
      this.$confirm(`确认删除${item.productName}？`, '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(_ => {
        this.formData.resultDtoList.splice(index, 1)
        if (item.productId === this.formData.productId) {
          this.formData.productId = this.formData.resultDtoList[0]?.productId || ''
          this.$refs.deviceListRef && this.$refs.deviceListRef.calcTableHeight()
        }
      }).catch(_ => _)
    },

    showDialog(dialog) {
      this[dialog] = true
    }
  }
}
</script>
<style lang="scss" scoped>
.function-page {
  display: flex;
  flex-direction: column;
  height: 100%;
  row-gap: 10px;

  .title-box {
    background-color: #fff;
    height: 60px;
    display: flex;
    align-items: center;
    box-shadow: 0 0 4px 0 rgba(0, 0, 0, 0.1);
    padding: 0 20px;
  }

  .form-content {
    flex: 1;
    display: flex;
    flex-direction: column;
    padding: 30px 20px 20px;
    background-color: #fff;
    box-shadow: 0 0 4px 0 rgba(0, 0, 0, 0.1);
    position: relative;
    box-sizing: border-box;

    ::v-deep .el-form {


      .tage-content {
        display: flex;
        margin-top: 2px;
        column-gap: 10px;
        row-gap: 10px;
        flex-wrap: wrap;

        .el-button {
          span {
            font-size: 12px;
          }
        }

        .el-tag {
          user-select: none;
          cursor: pointer;
        }
      }
    }

    .equip-table-content {
      flex: 1;
    }

    .btn-content {
      display: flex;
      justify-content: right;
      margin-top: 20px;
    }
  }

}

</style>
